@@ -15,7 +15,6 @@ from jupyterhubutils import Loggable, LSSTMiddleManager, LSSTConfig
 from jupyterhubutils.utils import (list_digest, str_true, assemble_gids,
                                    get_supplemental_gids)
 from ..helpers.extract_user_from_req import extract_user_from_req
-from ..spawner.spawner import MockSpawner
 from ..auth.auth import AuthenticatorMiddleware as AM
 
 
@@ -52,9 +51,6 @@ class LSSTWorkflowManager(Loggable):
         self.log.debug(
             "Creating new workflow manager with user '{}'".format(
                 self.user.escaped_name))
-        self.auth = AM(parent=self)
-        self.auth.process_request(req, None)  # Sets up authenticator's
-        # cached_auth_state
         self.core_api = self._get_corev1api()
         self.wf_api = self._get_wf_api()
 
@@ -132,9 +128,11 @@ class LSSTWorkflowManager(Loggable):
             lm = LSSTMiddleManager(parent=self,
                                    config=LSSTConfig(),
                                    user=self.user,
-                                   spawner=MockSpawner(parent=self),
-                                   authenticator=self.auth)
-            lm.spawner.user = self.user
+                                   authenticator=AM(parent=self))
+            lm.authenticator.set_auth_fields(self.user)
+            # That created a spawner on the authenticator with correct
+            #  fields.
+            lm.spawner = lm.authenticator.spawner
             cfg = lm.config
             em = lm.env_mgr
             vm = lm.volume_mgr
@@ -399,18 +397,20 @@ class LSSTWorkflowManager(Loggable):
             lm = LSSTMiddleManager(parent=self,
                                    config=LSSTConfig(),
                                    user=user,
-                                   spawner=MockSpawner(parent=self),
-                                   authenticator=self.auth)
-            # our users both have escaped_name fields
+                                   authenticator=AM(parent=self))
+            # That created a spawner on the authenticator with correct
+            #  fields.
+            lm.authenticator.set_auth_fields(self.user)
+            lm.spawner = lm.authenticator.spawner
             nm = lm.namespace_mgr
             nm.namespace = user.namespace
-            lm.spawner.user = user
             qm = lm.quota_mgr
             om = lm.optionsform_mgr
             om._make_sizemap()  # Guess it should be a public method.
             qm.define_resource_quota_spec()
-            nm.ensure_namespace()
-            nm.ensure_namespaced_service_account()
+            # Not setting up workflows with a daskconfig.  Might need to
+            #  in the future.
+            nm.ensure_namespace(namespace=user.namespace)
             wf = self.create_workflow()
             return wf
 
