@@ -1,13 +1,14 @@
 from eliot import log_call
 from jupyterhubutils import LoggableChild
+from ..objects.workflowmanager import LSSTWorkflowManager
 
 
 class List(LoggableChild):
 
     @log_call
     def on_get(self, req, resp):
-        wfm = self.parent.lsst_mgr.workflow_mgr
-        wfs = wfm.list_workflows()
+        wm = LSSTWorkflowManager(req=req)
+        wfs = wm.list_workflows()
         if not wfs:
             resp.media = []
             return
